==> cloud-3.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Entity/OpenStackInstance.php <==
<?php

namespace Drupal\openstack\Entity;

use Drupal\aws_cloud\Entity\Ec2\Instance;
use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the OpenStack Instance entity.
 *
 * @ingroup openstack
 *
 * @ContentEntityType(
 *   id = "openstack_instance",
 *   label = @Translation("Instance"),
 *   id_plural = "openstack_instances",
 *   label_collection = @Translation("Instances"),
 *   label_singular = @Translation("Instance"),
 *   label_plural = @Translation("Instances"),
 *   handlers = {
 *     "view_builder" = "Drupal\aws_cloud\Entity\Ec2\InstanceViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudContentListBuilder",
 *     "views_data" = "Drupal\openstack\Entity\OpenStackInstanceViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "add" = "Drupal\openstack\Form\OpenStackInstanceLaunchForm",
 *       "edit" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "delete" = "Drupal\openstack\Form\OpenStackInstanceDeleteForm",
 *       "start" = "Drupal\openstack\Form\OpenStackInstanceStartForm",
 *       "stop" = "Drupal\openstack\Form\OpenStackInstanceStopForm",
 *       "reboot" = "Drupal\openstack\Form\OpenStackInstanceRebootForm",
 *       "delete-multiple-confirm" = "Drupal\openstack\Form\OpenStackInstanceDeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\aws_cloud\Controller\Ec2\InstanceAccessControlHandler",
 *   },
 *   base_table = "openstack_instance",
 *   admin_permission = "administer openstack instance entities",
 *   fieldable = TRUE,
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "uid",
 *   },
 *   links = {
 *     "canonical" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}",
 *     "edit-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/edit",
 *     "delete-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/terminate",
 *     "collection" = "/clouds/openstack/{cloud_context}/instance",
 *     "start-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/start",
 *     "stop-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/stop",
 *     "reboot-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/reboot",
 *     "delete-multiple-form" = "/clouds/openstack/{cloud_context}/instance/delete_multiple",
 *   },
 *   field_ui_base_route = "openstack_instance.settings"
 * )
 */
class OpenStackInstance extends Instance implements InstanceInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['instance_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Instance Type'))
      ->setDescription(t("The type of instance determines your instance's CPU capacity, memory, and storage (e.g., m1.small, c1.xlarge)."))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['security_groups'] = BaseFieldDefinition::create('string_long')
      ->setLabel(t('Security Groups'))
      ->setDescription(t('The security groups to which the instance belongs. A security group is a collection of firewall rules that restrict the network traffic for the instance. Click View rules to see the rules for the specific group.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_security_group',
          'field_name' => 'name',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['private_ips'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Private IPs'))
      ->setDescription(t('The private IP address of the instance (multiple IP addresses are listed if there is more than one network interface to the instance).'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'public_ip',
          'html_generator_class' => OpenStackPublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['key_pair_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Key Pair Name'))
      ->setDescription(t('The name of the key pair that you must use to log in to the instance securely.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_key_pair',
          'field_name' => 'key_pair_name',
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['block_devices'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Volume'))
      ->setDescription(t('The Amazon EBS volumes attached to this instance.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_volume',
          'field_name' => 'volume_id',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    return $fields;
  }

}

==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Entity/OpenStackInstance.php <==
<?php

namespace Drupal\openstack\Entity;

use Drupal\aws_cloud\Entity\Ec2\Instance;
use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\aws_cloud\Entity\Ec2\PublicIpEntityLinkHtmlGenerator;

/**
 * Defines the OpenStack Instance entity.
 *
 * @ingroup openstack
 *
 * @ContentEntityType(
 *   id = "openstack_instance",
 *   label = @Translation("Instance"),
 *   id_plural = "openstack_instances",
 *   label_collection = @Translation("Instances"),
 *   label_singular = @Translation("Instance"),
 *   label_plural = @Translation("Instances"),
 *   handlers = {
 *     "view_builder" = "Drupal\aws_cloud\Entity\Ec2\InstanceViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudContentListBuilder",
 *     "views_data" = "Drupal\openstack\Entity\OpenStackInstanceViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "add" = "Drupal\openstack\Form\OpenStackInstanceLaunchForm",
 *       "edit" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "delete" = "Drupal\openstack\Form\OpenStackInstanceDeleteForm",
 *       "start" = "Drupal\openstack\Form\OpenStackInstanceStartForm",
 *       "stop" = "Drupal\openstack\Form\OpenStackInstanceStopForm",
 *       "reboot" = "Drupal\openstack\Form\OpenStackInstanceRebootForm",
 *       "delete-multiple-confirm" = "Drupal\openstack\Form\OpenStackInstanceDeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\aws_cloud\Controller\Ec2\InstanceAccessControlHandler",
 *   },
 *   base_table = "openstack_instance",
 *   admin_permission = "administer openstack instance entities",
 *   fieldable = TRUE,
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "uid",
 *   },
 *   links = {
 *     "canonical" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}",
 *     "edit-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/edit",
 *     "delete-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/terminate",
 *     "collection" = "/clouds/openstack/{cloud_context}/instance",
 *     "start-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/start",
 *     "stop-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/stop",
 *     "reboot-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/reboot",
 *     "delete-multiple-form" = "/clouds/openstack/{cloud_context}/instance/delete_multiple",
 *   },
 *   field_ui_base_route = "openstack_instance.settings"
 * )
 */
class OpenStackInstance extends Instance implements InstanceInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['instance_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Instance Type'))
      ->setDescription(t("The type of instance determines your instance's CPU capacity, memory, and storage (e.g., m1.small, c1.xlarge)."))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['security_groups'] = BaseFieldDefinition::create('string_long')
      ->setLabel(t('Security Groups'))
      ->setDescription(t('The security groups to which the instance belongs. A security group is a collection of firewall rules that restrict the network traffic for the instance. Click View rules to see the rules for the specific group.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_security_group',
          'field_name' => 'name',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['public_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Public IP'))
      ->setDescription(t('The Public IP.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'public_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -8,
      ])
      ->setReadOnly(TRUE);

    $fields['private_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Private IPs'))
      ->setDescription(t('The private IP address of the instance (multiple IP addresses are listed if there is more than one network interface to the instance).'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'private_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -7,
      ])
      ->setReadOnly(TRUE);

    $fields['key_pair_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Key Pair Name'))
      ->setDescription(t('The name of the key pair that you must use to log in to the instance securely.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_key_pair',
          'field_name' => 'key_pair_name',
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['block_devices'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Volume'))
      ->setDescription(t('The Amazon EBS volumes attached to this instance.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_volume',
          'field_name' => 'volume_id',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    return $fields;
  }

}
